Package: survPen
Title: Multidimensional Penalized Splines for (Excess) Hazard Models,
        Relative Mortality Ratio Models and Marginal Intensity Models
Version: 2.0.5
Authors@R: c(person(given = "Mathieu",
                        family = "Fauvernier",
                        role = c("aut", "cre"),
                        email = "mathieu.fauvernier@gmail.com"),
                 person(given = "Laurent",
                        family = "Roche",
                        role = "aut"),
                 person(given = "Laurent",
                        family = "Remontet",
                        role = "aut"),
                 person(given = "Zoe",
                        family = "Uhry",
                        role = "ctb"),
                 person(given = "Nadine",
                        family = "Bossard",
                        role = "ctb"),
                 person(given = "Elsa",
                        family = "Coz",
                        role = "ctb"))
Description: Fits (excess) hazard, relative mortality ratio or marginal intensity models with multidimensional penalized splines allowing for 
        time-dependent effects, non-linear effects and interactions between several continuous covariates. In survival and net survival analysis, in addition to modelling the effect of time (via the baseline hazard), one has often to deal with several continuous covariates and model their functional forms, their time-dependent effects, and their interactions. Model specification becomes therefore a complex problem and penalized regression splines represent an appealing solution to that problem as splines offer the required flexibility while penalization limits overfitting issues. Current implementations of penalized survival models can be slow or unstable and sometimes lack some key features like taking into account expected mortality to provide net survival and excess hazard estimates. In contrast, survPen provides an automated, fast, and stable implementation (thanks to explicit calculation of the derivatives of the likelihood) and offers a unified framework for 
        multidimensional penalized hazard and excess hazard models. Later versions (>2.0.0) include penalized models for relative mortality ratio, and marginal intensity in recurrent event setting.
	survPen may be of interest to those who 1) analyse any kind of time-to-event data: mortality, disease relapse, machinery breakdown, unemployment, etc 2) wish to describe the associated hazard and to understand which predictors impact its dynamics, 
	3) wish to model the relative mortality ratio between a cohort and a reference population, 4) wish to describe the marginal intensity for recurrent event data. 
	See Fauvernier et al. (2019a) <doi:10.21105/joss.01434> for an overview of the package and Fauvernier et al. (2019b) <doi:10.1111/rssc.12368> for the method.
Depends: R (>= 4.0.0)
License: GPL-3 | file LICENSE
Imports: statmod, stats, Rcpp (>= 1.0.2)
LinkingTo: Rcpp, RcppEigen
URL: https://github.com/fauvernierma/survPen
BugReports: https://github.com/fauvernierma/survPen/issues
Encoding: UTF-8
LazyData: true
Suggests: knitr, rmarkdown, testthat
VignetteBuilder: knitr
NeedsCompilation: yes
Packaged: 2026-06-09 09:06:22 UTC; fauvernierma
Repository: CRAN
Date/Publication: 2026-06-09 10:00:02 UTC
Author: Mathieu Fauvernier [aut, cre],
  Laurent Roche [aut],
  Laurent Remontet [aut],
  Zoe Uhry [ctb],
  Nadine Bossard [ctb],
  Elsa Coz [ctb]
Maintainer: Mathieu Fauvernier <mathieu.fauvernier@gmail.com>
Config/roxygen2/version: 8.0.0
RoxygenNote: 7.3.3
Built: R 4.6.0; aarch64-apple-darwin23; 2026-06-09 11:54:13 UTC; unix
Archs: survPen.so.dSYM
