# Generated by roxygen2: do not edit by hand

S3method(predict,survPen)
S3method(print,summary.survPen)
S3method(summary,survPen)
export("%cross%")
export("%mult%")
export("%vec%")
export(CumulHazard)
export(DerivCumulHazard)
export(HazGL)
export(Hess_rho)
export(Hess_rho_mult)
export(NR.beta)
export(NR.rho)
export(colSums2)
export(constraint)
export(crs)
export(crs.FP)
export(deriv_R)
export(design.matrix)
export(grad_rho)
export(grad_rho_mult)
export(instr)
export(model.cons)
export(predSNS)
export(pwcst)
export(rd)
export(repam)
export(smf)
export(smooth.cons)
export(smooth.cons.integral)
export(smooth.spec)
export(splitmult)
export(survPen)
export(survPen.fit)
export(tensor.in)
export(tensor.prod.S)
export(tensor.prod.X)
importFrom(Rcpp,sourceCpp)
useDynLib(survPen)
