% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/RcppExports.R
\name{colSums2}
\alias{colSums2}
\title{colSums of a matrix}
\usage{
colSums2(Mat)
}
\arguments{
\item{Mat}{a matrix.}
}
\value{
colSums(Mat)
}
\description{
colSums of a matrix
}
